@@ -897,9 +897,6 @@ class DeliveryOrderClient(EntityClientBase):
     def slack_report_send(self, params):
         return self.http_post_json(self.entity_endpoint_base_url + "_slack-report-send", params)
 
-    def set_packed_items(self, params):
-        return self.http_post_json(self.entity_endpoint_base_url + "_set-packed_items", params)
-
     def set_packed_items(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_set-packed_items".format(id), params)
 
